==> cineast-proto-0.1.0-sources.jar: main/java/org/vitrivr/cineast/api/grpc/CineastManageGrpc.java <==
package org.vitrivr.cineast.api.grpc;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.33.1)",
    comments = "Source: cineast.proto")
public final class CineastManageGrpc {

  private CineastManageGrpc() {}

  public static final String SERVICE_NAME = "org.vitrivr.cineast.api.grpc.CineastManage";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp,
      org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> getPingMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Ping",
      requestType = org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp.class,
      responseType = org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp,
      org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> getPingMethod() {
    io.grpc.MethodDescriptor<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp, org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> getPingMethod;
    if ((getPingMethod = CineastManageGrpc.getPingMethod) == null) {
      synchronized (CineastManageGrpc.class) {
        if ((getPingMethod = CineastManageGrpc.getPingMethod) == null) {
          CineastManageGrpc.getPingMethod = getPingMethod =
              io.grpc.MethodDescriptor.<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp, org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Ping"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp.getDefaultInstance()))
              .setSchemaDescriptor(new CineastManageMethodDescriptorSupplier("Ping"))
              .build();
        }
      }
    }
    return getPingMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static CineastManageStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastManageStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastManageStub>() {
        @java.lang.Override
        public CineastManageStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastManageStub(channel, callOptions);
        }
      };
    return CineastManageStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static CineastManageBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastManageBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastManageBlockingStub>() {
        @java.lang.Override
        public CineastManageBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastManageBlockingStub(channel, callOptions);
        }
      };
    return CineastManageBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static CineastManageFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastManageFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastManageFutureStub>() {
        @java.lang.Override
        public CineastManageFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastManageFutureStub(channel, callOptions);
        }
      };
    return CineastManageFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class CineastManageImplBase implements io.grpc.BindableService {

    /**
     */
    public void ping(org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp request,
        io.grpc.stub.StreamObserver<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> responseObserver) {
      asyncUnimplementedUnaryCall(getPingMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getPingMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp,
                org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp>(
                  this, METHODID_PING)))
          .build();
    }
  }

  /**
   */
  public static final class CineastManageStub extends io.grpc.stub.AbstractAsyncStub<CineastManageStub> {
    private CineastManageStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastManageStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastManageStub(channel, callOptions);
    }

    /**
     */
    public void ping(org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp request,
        io.grpc.stub.StreamObserver<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getPingMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class CineastManageBlockingStub extends io.grpc.stub.AbstractBlockingStub<CineastManageBlockingStub> {
    private CineastManageBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastManageBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastManageBlockingStub(channel, callOptions);
    }

    /**
     */
    public org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp ping(org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp request) {
      return blockingUnaryCall(
          getChannel(), getPingMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class CineastManageFutureStub extends io.grpc.stub.AbstractFutureStub<CineastManageFutureStub> {
    private CineastManageFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastManageFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastManageFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> ping(
        org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp request) {
      return futureUnaryCall(
          getChannel().newCall(getPingMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_PING = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final CineastManageImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(CineastManageImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_PING:
          serviceImpl.ping((org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp) request,
              (io.grpc.stub.StreamObserver<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class CineastManageBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    CineastManageBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.vitrivr.cineast.api.grpc.CineastGrpc.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("CineastManage");
    }
  }

  private static final class CineastManageFileDescriptorSupplier
      extends CineastManageBaseDescriptorSupplier {
    CineastManageFileDescriptorSupplier() {}
  }

  private static final class CineastManageMethodDescriptorSupplier
      extends CineastManageBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    CineastManageMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (CineastManageGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new CineastManageFileDescriptorSupplier())
              .addMethod(getPingMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> cineast-proto-0.1.2-sources.jar: main/java/org/vitrivr/cineast/api/grpc/CineastManageGrpc.java <==
package org.vitrivr.cineast.api.grpc;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.44.0)",
    comments = "Source: cineast.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class CineastManageGrpc {

  private CineastManageGrpc() {}

  public static final String SERVICE_NAME = "org.vitrivr.cineast.api.grpc.CineastManage";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp,
      org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> getPingMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Ping",
      requestType = org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp.class,
      responseType = org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp,
      org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> getPingMethod() {
    io.grpc.MethodDescriptor<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp, org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> getPingMethod;
    if ((getPingMethod = CineastManageGrpc.getPingMethod) == null) {
      synchronized (CineastManageGrpc.class) {
        if ((getPingMethod = CineastManageGrpc.getPingMethod) == null) {
          CineastManageGrpc.getPingMethod = getPingMethod =
              io.grpc.MethodDescriptor.<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp, org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Ping"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp.getDefaultInstance()))
              .setSchemaDescriptor(new CineastManageMethodDescriptorSupplier("Ping"))
              .build();
        }
      }
    }
    return getPingMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static CineastManageStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastManageStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastManageStub>() {
        @java.lang.Override
        public CineastManageStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastManageStub(channel, callOptions);
        }
      };
    return CineastManageStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static CineastManageBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastManageBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastManageBlockingStub>() {
        @java.lang.Override
        public CineastManageBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastManageBlockingStub(channel, callOptions);
        }
      };
    return CineastManageBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static CineastManageFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<CineastManageFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<CineastManageFutureStub>() {
        @java.lang.Override
        public CineastManageFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new CineastManageFutureStub(channel, callOptions);
        }
      };
    return CineastManageFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class CineastManageImplBase implements io.grpc.BindableService {

    /**
     */
    public void ping(org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp request,
        io.grpc.stub.StreamObserver<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getPingMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getPingMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp,
                org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp>(
                  this, METHODID_PING)))
          .build();
    }
  }

  /**
   */
  public static final class CineastManageStub extends io.grpc.stub.AbstractAsyncStub<CineastManageStub> {
    private CineastManageStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastManageStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastManageStub(channel, callOptions);
    }

    /**
     */
    public void ping(org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp request,
        io.grpc.stub.StreamObserver<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getPingMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class CineastManageBlockingStub extends io.grpc.stub.AbstractBlockingStub<CineastManageBlockingStub> {
    private CineastManageBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastManageBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastManageBlockingStub(channel, callOptions);
    }

    /**
     */
    public org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp ping(org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getPingMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class CineastManageFutureStub extends io.grpc.stub.AbstractFutureStub<CineastManageFutureStub> {
    private CineastManageFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected CineastManageFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new CineastManageFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp> ping(
        org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getPingMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_PING = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final CineastManageImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(CineastManageImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_PING:
          serviceImpl.ping((org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp) request,
              (io.grpc.stub.StreamObserver<org.vitrivr.cineast.api.grpc.CineastGrpc.TimeStamp>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class CineastManageBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    CineastManageBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.vitrivr.cineast.api.grpc.CineastGrpc.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("CineastManage");
    }
  }

  private static final class CineastManageFileDescriptorSupplier
      extends CineastManageBaseDescriptorSupplier {
    CineastManageFileDescriptorSupplier() {}
  }

  private static final class CineastManageMethodDescriptorSupplier
      extends CineastManageBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    CineastManageMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (CineastManageGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new CineastManageFileDescriptorSupplier())
              .addMethod(getPingMethod())
              .build();
        }
      }
    }
    return result;
  }
}
